@@ -5,11 +5,11 @@
 #' @param model a three characters string to specify the
 #' smoothness alpha (each one as integer) parameters.
 #' Currently it considers the `102`, `121`, `202` and `220` models.
-#' @param control.priors a named list with parameter priors.
-#' E.g. prior.rs, prior.rt and prior.sigma
-#' as vectors with length two (U, a) to define the
-#' corresponding PC-prior such that
-#' P(r_s<U)=a, P(r_t<U)=a or P(sigma>U)=a.
+#' @param control.priors a named list with parameter priors,
+#' named as `prs`, `prt` and `psigma`, each one as a vector
+#' with length two containing (U, a) to define the
+#' corresponding PC-prior such that, respectively,
+#' P(range.spatial<U)=a, P(range.temporal<U)=a or P(sigma>U)=a.
 #' If a=0 then U is taken to be the fixed value of the parameter.
 #' @param constr logical to indicate if the integral of the field
 #' over the domain is to be constrained to zero. Default value is FALSE.
@@ -25,9 +25,11 @@
 #' [stModel.matrices] and the parameters are as Eq (19-21),
 #' but parametrized in log scale.
 #' @return objects to be used in the f() formula term in INLA.
-#' @references Lindgren et. al. (2024).
+#' @references
+#' Finn Lindgren, Haakon Bakka, David Bolin, Elias Krainski and Håvard Rue (2024).
 #' A diffusion-based spatio-temporal extension of Gaussian Matérn fields.
 #' [SORT 48 (1), 3-66](https://www.idescat.cat/sort/sort481/48.1.1.Lindgren-etal.pdf)
+#' <doi: 10.57645/20.8080.02.13>
 #' @export
 #' @importFrom fmesher fm_manifold
 stModel.define <-
@@ -42,10 +44,41 @@ stModel.define <-
     dimension <- fm_manifold_dim(smesh)
     stopifnot(dimension > 0)
 
+    stopifnot(length(control.priors$prt)==2)
+    stopifnot(length(control.priors$prs)==2)
+    stopifnot(length(control.priors$psigma)==2)
+
+    stopifnot(control.priors$prt[1]>0)
+    stopifnot(control.priors$prs[1]>0)
+    stopifnot(control.priors$psigma[1]>0)
+
+    stopifnot(control.priors$prt[2]>=0)
+    stopifnot(control.priors$prs[2]>=0)
+    stopifnot(control.priors$psigma[2]>=0)
+
+    stopifnot(control.priors$prt[2]<1)
+    stopifnot(control.priors$prs[2]<1)
+    stopifnot(control.priors$psigma[2]<1)
+
+    INLAversion <- check_package_version_and_load(
+      pkg = "INLA",
+      minimum_version = "23.08.16",
+      quietly = TRUE
+    )
     if (is.null(libpath)) {
+      if(length(useINLAprecomp)>1) {
+        warning("length(useINLAprecomp)>1, first taken!")
+        useINLAprecomp <- useINLAprecomp[1]
+      }
+      stopifnot(is.logical(useINLAprecomp))
+      if(is.na(INLAversion) & useINLAprecomp) {
+        stop("Update INLA or try `useINLAprecomp = FALSE`!")
+      }
       if (useINLAprecomp) {
+        hasverbose <- (INLAversion<="25.02.10") ## to work with old C versions
         libpath <- INLA::inla.external.lib("INLAspacetime")
       } else {
+        hasverbose <- FALSE
         libpath <- system.file("libs", package = "INLAspacetime")
         if (Sys.info()["sysname"] == "Windows") {
           libpath <- file.path(libpath, "INLAspacetime.dll")
@@ -53,6 +86,8 @@ stModel.define <-
           libpath <- file.path(libpath, "INLAspacetime.so")
         }
       }
+    } else {
+      hasverbose <- FALSE ## assumed...
     }
     stopifnot(file.exists(libpath))
 
@@ -101,13 +136,20 @@ stModel.define <-
     lmats <- upperPadding(mm[jmm], relative = FALSE)
     stopifnot(n == nrow(lmats$graph))
 
+    args0 <- list(
+      model = "inla_cgeneric_sstspde",
+      shlib = libpath,
+      n = as.integer(n),
+      debug = as.integer(debug)
+      )
+    if(hasverbose) { ## to work with old C versions
+      args0$verbose <- as.integer(0)
+    }
+
     the_model <- do.call(
       "inla.cgeneric.define",
-      list(
-        model = "inla_cgeneric_sstspde",
-        shlib = libpath,
-        n = n,
-        debug = as.integer(debug),
+      c(args0,
+        list(
         Rmanifold = as.integer(Rmanifold),
         dimension = as.integer(dimension),
         aaa = as.integer(alphas),
@@ -121,7 +163,7 @@ stModel.define <-
         jj = lmats$graph@j,
         tt = t(mm$TT),
         xx = t(lmats$xx)
-      )
+      ))
     )
     if (constr) {
       the_model$f$extraconstr <- mm$extraconstr
